@@ -7,6 +7,6 @@ class GoogleDriveStorageConf(AppConf):
 
     class Meta:
         prefix = 'GOOGLE_DRIVE_STORAGE'
-        required = ['KEY', 'SERVICE_EMAIL']
+        required = ['JSON_KEY_FILE']
 
     USER_EMAIL = None
\ No newline at end of file
